{
  description = "terraform-provider-tor";
  inputs = {
    nixpkgs.url = "https://flakehub.com/f/NixOS/nixpkgs/0.1"; # tracks nixpkgs unstable branch
  };
  outputs =
    inputs:
    let
      supportedSystems = [
        "x86_64-linux"
        "aarch64-darwin"
      ];
      forEachSupportedSystem =
        f:
        inputs.nixpkgs.lib.genAttrs supportedSystems (
          system:
          f {
            pkgs = import inputs.nixpkgs {
              inherit system;
              overlays = [
                inputs.self.overlays.default
              ];
            };
            pkgs-mine = import inputs.nixpkgs-mine {
              inherit system;
              overlays = [
                inputs.self.overlays.default
              ];
            };
          }
        );
    in
    {
      overlays.default = final: prev: {
        tor = prev.tor.overrideAttrs (
          old:
          let
            pname = "tor";
            version = "0.4.9.2-alpha";
          in
          {
            version = version;
            src = prev.fetchurl {
              url = "https://dist.torproject.org/${pname}-${version}.tar.gz";
              hash = "sha256-uUJc92dwLXGISOiEdJjg1G8qJhuHp7Qk3BjSOZUxABo=";
            };
          }
        );
      };

      devShells = forEachSupportedSystem (
        { pkgs, pkgs-mine }:
        let
          libraries = [
          ];
        in
        {
          default = pkgs.mkShell {
            packages = [
              pkgs.go
              pkgs.gopls
              pkgs.golangci-lint
              pkgs.obfs4
              pkgs.gnumake
              pkgs.opentofu
              pkgs.tor
            ];
            buildInputs = libraries;
            inputsFrom = libraries;
            nativeBuildInputs = [ pkgs.pkg-config ];
            env.LD_LIBRARY_PATH = pkgs.lib.makeLibraryPath libraries;
          };
        }
      );
    };
}
